import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';
// to fill the pie chart sections with colors
const sectionColors = [
  		'lightgreen', 'green', 'blue', 'red', 'brown', 'yellow', 'pink', 'violet', 'orange', 'purple','grey'
		  ];

// linking the dataset created in gist github
const csvUrl = 'https://gist.githubusercontent.com/saivinay143/048aeeb8e022f2551ede9eb3ff3c2ffd/raw/89258aa63505c881f9fbaf42559537f37062c1a5/usapopulation.csv';
// loading the URL by fetchdata method
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

// TickFormat function to x-axis
const xAxisTickFormat = number =>
  	format('.4~g')(number);

//  to create pie chart
const render = (data, total) => {
  const pieData = pie().value(d=>d.count)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
    // to generate arcs for every section
  const arcGenerator = d3.arc()
  .innerRadius(5)
  .outerRadius(270);

  
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(170)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(225,225)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.count));
  // to add text on each section
  sections
    .enter()
    .append('text')
    .text(d => xAxisTickFormat((d.data.count/10))+"k")
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "right")
  	.style('fill', 'Black')
    .style("font-size", 13);
   //  to add legends on the chart
  const legends = svg.append("g")
  	.attr("transform", "translate(600,75)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",22).attr("height",25)
  	.attr("fill", d => colors(d.data.count));
  legend.append("text")
  	.attr("x", 30)
  	.attr("y", 20)
  	.attr("class","legend_text")
  	.text(d => d.data.State);
  legend.append("text")
  	.attr("x", 270)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.count/10))+"k");
}
// main function to run the code
const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.count = +d.count;
    total += d.count
  });
	render(data,total);
};
run();